%define anolis_release 1
%global __cmake_in_source_build 1
%bcond_with docs

Name:         libipt
Version:      2.1
Release:      %{anolis_release}%{?dist}
Summary:      Intel Processor Trace Decoder Library
License:      BSD-3-Clause
URL:          https://github.com/intel/libipt
Source0:      https://github.com/intel/libipt/archive/v%{version}.tar.gz
Source1:      doc-v%{version}.tar.xz

# https://github.com/intel/libipt/commit/0144bc2fa99421725585dbc7ecbe2e412f7f8d27
Patch0001:    libipt-pttc-lto-fix-lto-strlen-size-warning.patch
# https://github.com/intel/libipt/commit/0c2e3594499f89f54dab6f965ea54a7f0a45348f
Patch0002:    libipt-ptunit-avoid-lto-maybe-uninitialized-warning.patch

BuildRequires: gcc-c++ cmake make
%if 0%{?_with_docs:1}
BuildRequires: pandoc
%endif

ExclusiveArch: x86_64 loongarch64

%description
The Intel Processor Trace (Intel PT) Decoder Library is Intel's reference
implementation for decoding Intel PT.  It can be used as a standalone library
or it can be partially or fully integrated into your tool.

The library comes with a set of sample tools built on top of it and a test
system built on top of the sample tools.  The samples demonstrate how to use the
library and may serve as a starting point for integrating the library into your
tool.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary:      Header files and libraries for Intel Processor Trace Decoder Library
Requires:     %{name} = %{EVR}
ExclusiveArch: x86_64 loongarch64

%description devel
The %{name}-devel package contains the header files and libraries needed to
develop programs that use the Intel Processor Trace (Intel PT) Decoder Library.

%prep
%autosetup -p1

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DPTUNIT:BOOL=ON \
%if 0%{?_with_docs:1}
       -DMAN:BOOL=ON \
%endif
       -DDEVBUILD:BOOL=ON \
       .
%make_build

%install
%make_install
%global develdocs howto_libipt.md
(cd doc;cp -p %{develdocs} ..)

# If not building documentation, copy the pre-generated man pages
# to the appropriate place. Otherwise, tar up the generated
# documentation for use in subsequent builds.
%if 0%{?_with_docs:1}
(cd $RPM_BUILD_ROOT%{_mandir}/..; %__tar cJf %{SOURCE1} .)
%else
mkdir -p $RPM_BUILD_ROOT%{_mandir}
(cd $RPM_BUILD_ROOT%{_mandir}/..; %__tar xJf %{SOURCE1})
%endif

%generate_compatibility_deps

%check
ctest -V %{?_smp_mflags}

%files
%dir %{abidir}
%license LICENSE
%{_libdir}/%{name}.so.*
%{abidir}/%{name}*.dump

%files doc
%doc README

%files devel
%doc %{develdocs}
%{_includedir}/*
%{_libdir}/%{name}.so
%{_mandir}/*/*.zst

%changelog
* Mon Feb 17 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.1-1
- Update to 2.1 from 2.0.5
- Migrated to SPDX license
- Add patches to fix err with strnlen specified bound size outweigh source size
- Add patches to fix err with the decoder object isn't actually used
  [Patches cherry-picked from c10s. Original changelog:
  - Update to v2.1 and regenerate documentation(2.1-1)]

* Mon Sep 25 2023 Wenlong Zhang <zhangwenlong@loongson.cn> - 2.0.5-6
- Add loongarch64 support

* Mon Apr 10 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 2.0.5-5
- Refactor the specfile

* Tue Mar 28 2023 happy_orange <songnannan@linux.alibaba.com> - 2.0.5-4
- disable pandoc

* Thu Mar 23 2023 chen_yu_ao <m15927509890@163.com> - 2.0.5-3
- optimise format and remove extra macro, change man/*.gz to .zst

* Mon Oct 24 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.0.5-2
- optimise spec file & add doc package

* Fri Apr 08 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.0.5-1
- Init from upstream version 2.0.5
